## Overview

This module contains the eABF/DRR method to do free energy calculation or enhance sampling along CVs.

### Installation

This module is not installed by default and depends on the boost serialization module. Please make sure the boost serialization library is 
compiled and installed in your system before trying to compile this module. Add '\-\-enable-modules=drr \-\-enable-boost_serialization' to your './configure' 
command when building PLUMED to enable these features.

### Usage

Please read the documentation for the actions and command line tools detailed below. 
